==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/actions/image/showin3d/ShowSagittalSliceIn3D.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "ShowSagittalSliceIn3D.h"

#include <ImageComponent.h>
#include <SingleImageComponent.h>
#include <InteractiveViewer.h>

using namespace camitk;

// --------------- constructor -------------------
ShowSagittalSliceIn3D::ShowSagittalSliceIn3D(ActionExtension * extension) : Action(extension) {
    // Setting name, description and input component
    setName("ShowSagittalSliceIn3D");
    setEmbedded(false);
    setDescription("Display or not the current slice(s) in 3D");
    setComponent("ImageComponent");
//	setComponent("SingleImageComponent");

    // Setting classification family and tags
    setFamily("Display");
    addTag("3D Viewer");

}

// --------------- destructor -------------------
ShowSagittalSliceIn3D::~ShowSagittalSliceIn3D() {
    // do not delete the widget has it might have been used in the ActionViewer (i.e. the ownership might have been taken by the stacked widget)
}

// --------------- getWidget --------------
QWidget * ShowSagittalSliceIn3D::getWidget() {
    return NULL;
}

// --------------- apply -------------------
Action::ApplyStatus ShowSagittalSliceIn3D::apply() {
    foreach (Component *comp, getTargets()) {
		ImageComponent * img = dynamic_cast<ImageComponent *> (comp);
		if(img) {
			img->getSagittalSlices()->setViewSliceIn3D(! img->getSagittalSlices()->getViewSliceIn3D());
		}
    }

    return SUCCESS;
}

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/actions/image/showin3d/ShowSagittalSliceIn3D.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "ShowSagittalSliceIn3D.h"

#include <ImageComponent.h>
#include <SingleImageComponent.h>
#include <InteractiveViewer.h>

using namespace camitk;

// --------------- constructor -------------------
ShowSagittalSliceIn3D::ShowSagittalSliceIn3D(ActionExtension * extension) : Action(extension) {
    // Setting name, description and input component
    setName("ShowSagittalSliceIn3D");
    setEmbedded(false);
    setDescription("Toggle display of the sagittal slice(s) in 3D");
    setComponent("ImageComponent");

    // Setting classification family and tags
    setFamily("Display");
    addTag("3D Viewer");
}

// --------------- destructor -------------------
ShowSagittalSliceIn3D::~ShowSagittalSliceIn3D() {
    // do not delete the widget has it might have been used in the ActionViewer (i.e. the ownership might have been taken by the stacked widget)
}

// --------------- getWidget --------------
QWidget * ShowSagittalSliceIn3D::getWidget() {
    return NULL;
}

// --------------- apply -------------------
Action::ApplyStatus ShowSagittalSliceIn3D::apply() {
    foreach (Component *comp, getTargets()) {
        ImageComponent * img = dynamic_cast<ImageComponent *> (comp);
        if(img) {
            img->getSagittalSlices()->setViewSliceIn3D(! img->getSagittalSlices()->getViewSliceIn3D());
        }
    }

    return SUCCESS;
}
